@@ -1,11 +1,11 @@
 """Toolkit for Object Detection Distillation."""
 from . import (
     adapts,
+    datasets,
     distillers,
     hooks,
     losses,
     reproduction,
-    schedulers,
     utils,
     visuals,
 )
@@ -13,13 +13,11 @@ from .base import *
 
 __all__ = [
     'adapts',
+    'datasets',
     'distillers',
     'hooks',
     'losses',
     'reproduction',
-    'schedulers',
     'utils',
     'visuals',
 ]
-__version__ = '0.0.1'
-__author__ = 'Luting Wang'
