@@ -2,10 +2,10 @@ import einops
 import torch
 import torch.nn as nn
 
-from .base import ADAPTS, BaseAdapt
+from .base import AdaptRegistry, BaseAdapt
 
 
-@ADAPTS.register_module()
+@AdaptRegistry.register()
 class Decouple(BaseAdapt):
 
     def __init__(
@@ -21,22 +21,20 @@ class Decouple(BaseAdapt):
         self._layer = nn.Linear(in_features, out_features * num, bias)
 
     def forward(self, feat: torch.Tensor, id_: torch.Tensor) -> torch.Tensor:
-        """Decouple `feat`.
+        """Decouple features.
 
         Args:
             feat: n x dim
             pos: n
 
         Returns:
-            decoupled_feat: n x dim
+            decoupled_feat n x dim
         """
-        decoupled_feat: torch.Tensor = self._layer(feat)  # n x (num x dim)
-        decoupled_feat = einops.rearrange(
-            decoupled_feat,
+        feat = self._layer(feat)  # n x (num x dim)
+        feat = einops.rearrange(
+            feat,
             'n (num dim) -> n num dim',
             num=self._num,
         )
-        decoupled_feat = decoupled_feat[  # yapf: disable
-            torch.arange(id_.shape[0]), id_.long(),
-        ]  # n x dim
-        return decoupled_feat
+        feat = feat[torch.arange(id_.shape[0]), id_.long()]  # n x dim
+        return feat
