@@ -1,27 +1,29 @@
-from typing import List
-
 import torch
-from mmcv.runner import ModuleList
 
-from .base import ADAPTS, BaseAdapt
+from ..base import ModuleList
+from .base import AdaptRegistry, BaseAdapt
 
 
-@ADAPTS.register_module()
+@AdaptRegistry.register()
 class RoIAlign(BaseAdapt):
 
-    def __init__(self, strides: List[int], *args, **kwargs):
-        from mmcv.ops import RoIAlign as RA
+    def __init__(self, strides: list[int], *args, **kwargs):
+        import mmcv.ops
+
         super().__init__(*args, **kwargs)
         self._layers = ModuleList([
-            RA(spatial_scale=1 / s, output_size=7, sampling_ratio=0)
-            for s in strides
+            mmcv.ops.RoIAlign(
+                spatial_scale=1 / s,
+                output_size=7,
+                sampling_ratio=0,
+            ) for s in strides
         ])
 
     def forward(
         self,
-        feats: List[torch.Tensor],
-        bboxes: List[torch.Tensor],
-    ) -> List[torch.Tensor]:
+        feats: list[torch.Tensor],
+        bboxes: list[torch.Tensor],
+    ) -> list[torch.Tensor]:
         """
         Args:
             feats: l x n x c x h x w
