@@ -1,39 +1,43 @@
 __all__ = [
+    'BBoxTuple',
     'BBoxesXYXY',
     'BBoxesXYWH',
 ]
 
-from abc import abstractmethod
-from typing import (
-    List,
-    NamedTuple,
-    Optional,
-    Sized,
-    Tuple,
-    Type,
-    TypeVar,
-    Union,
-)
+import numbers
+from abc import ABC, abstractmethod
+from typing import Generator, Sequence, TypeVar, overload
 
 import einops
 import numpy as np
 import torch
 
+BBoxTuple = tuple[numbers.Real, numbers.Real, numbers.Real, numbers.Real]
 T = TypeVar('T', bound='BBoxes')
 
 
-class BBoxes(Sized):
+class BBoxes(ABC):
 
-    def __init__(self, bboxes: Union[np.ndarray, torch.Tensor]) -> None:
+    def __init__(
+        self,
+        bboxes,
+    ) -> None:
         """
         Args:
             bboxes: \\* x 4
                 (x1, y1, x2, y2)
         """
-        if isinstance(bboxes, np.ndarray):
+        if isinstance(bboxes, BBoxes):
+            bboxes = self._convert(bboxes)
+        elif isinstance(bboxes, torch.Tensor):
+            pass
+        elif isinstance(bboxes, np.ndarray):
             bboxes = torch.from_numpy(bboxes)
-        if bboxes.numel() == 0:
-            raise ValueError('bboxes is empty')
+        elif not bboxes:
+            bboxes = torch.empty(0, 4)
+        else:
+            bboxes = torch.tensor(bboxes)
+
         if bboxes.ndim < 2:
             raise ValueError('bboxes must be at least 2-dim')
         if bboxes.shape[-1] != 4:
@@ -43,6 +47,16 @@ class BBoxes(Sized):
     def __len__(self) -> int:
         return self._bboxes.shape[0]
 
+    def __repr__(self) -> str:
+        return (
+            f'{self.__module__}.{self.__class__.__qualname__}({self._bboxes})'
+        )
+
+    @staticmethod
+    @abstractmethod
+    def _convert(bboxes: 'BBoxes') -> torch.Tensor:
+        pass
+
     @property
     @abstractmethod
     def left(self) -> torch.Tensor:
@@ -107,15 +121,11 @@ class BBoxes(Sized):
         return self._bboxes
 
     @property
-    def shapes(self) -> torch.Tensor:
-        return self.wh
-
-    @property
-    def areas(self) -> torch.Tensor:
+    def area(self) -> torch.Tensor:
         return self.width * self.height
 
     @classmethod
-    def _cat(cls: Type[T], a: T, b: T) -> T:
+    def _cat(cls: type[T], a: T, b: T) -> T:
         """
         Args:
             a: *1 x 4
@@ -133,12 +143,26 @@ class BBoxes(Sized):
     def __add__(self: T, other: T) -> T:
         return self.cat(other)
 
+    @overload
+    @classmethod
+    def _select(  # type: ignore[misc]
+        cls: type[T],
+        bboxes: T,
+        indices: slice | torch.Tensor | Sequence[int],
+    ) -> T:
+        ...
+
+    @overload
     @classmethod
     def _select(
-        cls: Type[T],
+        cls: type[T],
         bboxes: T,
-        indices: Union[int, slice, torch.Tensor, List[int], Tuple[int, ...]],
-    ) -> T:
+        indices: int,
+    ) -> BBoxTuple:
+        ...
+
+    @classmethod
+    def _select(cls: type[T], bboxes: T, indices):
         """
         Args:
             bboxes: n x 4
@@ -147,22 +171,45 @@ class BBoxes(Sized):
         Returns:
             bboxes: m x 4
         """
-        return cls(bboxes.to_tensor()[indices])
+        tensor = bboxes.to_tensor()[indices]
+        if tensor.ndim == 1:
+            return tuple(tensor.tolist())
+        return cls(tensor)
 
-    def select(
+    @overload
+    def select(  # type: ignore[misc]
         self: T,
-        indices: Union[int, slice, torch.Tensor, List[int], Tuple[int, ...]],
+        indices: slice | torch.Tensor | Sequence[int],
     ) -> T:
+        ...
+
+    @overload
+    def select(self: T, indices: int) -> BBoxTuple:
+        ...
+
+    def select(self, indices):
         return self._select(self, indices)
 
-    def __getitem__(
+    @overload
+    def __getitem__(  # type: ignore[misc]
         self: T,
-        indices: Union[int, slice, torch.Tensor, List[int], Tuple[int, ...]],
+        indices: slice | torch.Tensor | Sequence[int],
     ) -> T:
+        ...
+
+    @overload
+    def __getitem__(self: T, indices: int) -> BBoxTuple:
+        ...
+
+    def __getitem__(self, indices):
         return self.select(indices)
 
+    def __iter__(self) -> Generator[BBoxTuple, None, None]:
+        for i in range(len(self)):
+            yield self[i]  # type: ignore[misc]
+
     @classmethod
-    def _intersections(cls: Type[T], a: T, b: T) -> torch.Tensor:
+    def _intersections(cls, a: 'BBoxes', b: 'BBoxes') -> torch.Tensor:
         """
         Args:
             a: *1 x 4
@@ -183,18 +230,18 @@ class BBoxes(Sized):
         wh = wh.clamp_min_(0)
         return wh[..., 0] * wh[..., 1]
 
-    def intersections(self: T, other: T) -> torch.Tensor:
+    def intersections(self, other: 'BBoxes') -> torch.Tensor:
         return self._intersections(self, other)
 
-    def __and__(self: T, other: T) -> torch.Tensor:
+    def __and__(self, other: 'BBoxes') -> torch.Tensor:
         return self.intersections(other)
 
     @classmethod
     def _unions(
-        cls: Type[T],
-        a: T,
-        b: T,
-        intersections: Optional[torch.Tensor] = None,
+        cls,
+        a: 'BBoxes',
+        b: 'BBoxes',
+        intersections: torch.Tensor | None = None,
     ) -> torch.Tensor:
         """
         Args:
@@ -207,19 +254,19 @@ class BBoxes(Sized):
         """
         if intersections is None:
             intersections = cls.intersections(a, b)
-        return a.areas[:, None] + b.areas[None, :] - intersections
+        return a.area[:, None] + b.area[None, :] - intersections
 
     def unions(
-        self: T,
-        other: T,
-        intersections: Optional[torch.Tensor] = None,
+        self,
+        other: 'BBoxes',
+        intersections: torch.Tensor | None = None,
     ) -> torch.Tensor:
         return self._unions(self, other, intersections)
 
-    def __or__(self: T, other: T) -> torch.Tensor:
+    def __or__(self, other: 'BBoxes') -> torch.Tensor:
         return self.unions(other)
 
-    def ious(self: T, other: T, eps: float = 1e-6) -> torch.Tensor:
+    def ious(self, other: 'BBoxes', eps: float = 1e-6) -> torch.Tensor:
         """
         Args:
             a: *1 x 4
@@ -235,7 +282,7 @@ class BBoxes(Sized):
 
     @classmethod
     @abstractmethod
-    def _round(cls: Type[T], bboxes: T) -> T:
+    def _round(cls: type[T], bboxes: T) -> T:
         pass
 
     def round(self: T) -> T:
@@ -244,10 +291,9 @@ class BBoxes(Sized):
     @classmethod
     @abstractmethod
     def _expand(
-        cls: Type[T],
-        bboxes: T,
-        ratio: float,
-        image_shape: Optional[Tuple[int, int]] = None,
+        cls: type[T],
+        bboxes: 'BBoxes',
+        ratio_wh: tuple[float, float],
     ) -> T:
         """
         Args:
@@ -258,22 +304,91 @@ class BBoxes(Sized):
         """
         pass
 
+    @overload
     def expand(
         self: T,
-        ratio: float,
-        image_shape: Optional[Tuple[int, int]] = None,
+        ratio_wh: float,
     ) -> T:
-        return self._expand(self, ratio, image_shape)
+        ...
 
+    @overload
+    def expand(
+        self: T,
+        ratio_wh: tuple[float, float],
+    ) -> T:
+        ...
 
-T_XY = TypeVar('T_XY', bound='BBoxesXY')
+    def expand(self, ratio_wh):
+        if not isinstance(ratio_wh, tuple):
+            ratio_wh = (ratio_wh, ratio_wh)
+        return self._expand(self, ratio_wh)
+
+    def indices(
+        self,
+        *,
+        min_area: numbers.Real | None = None,
+        min_wh: tuple[int, int] | None = None,
+    ) -> torch.Tensor:
+        inds = self.to_tensor().new_ones(len(self), dtype=torch.bool)
+        if min_area is not None:
+            inds &= self.area.ge(min_area)
+        if min_wh is not None:
+            inds &= self.width.ge(min_wh[0])
+            inds &= self.height.ge(min_wh[1])
+        return inds
+
+    @classmethod
+    @abstractmethod
+    def _clamp(
+        cls: type[T],
+        bboxes: 'BBoxes',
+        image_wh: tuple[int, int],
+    ) -> T:
+        pass
+
+    def clamp(
+        self: T,
+        image_wh: tuple[int, int],
+    ) -> T:
+        return self._clamp(self, image_wh)
+
+    @classmethod
+    @abstractmethod
+    def _scale(
+        cls: type[T],
+        bboxes: 'BBoxes',
+        ratio_wh: tuple[float, float],
+    ) -> T:
+        """
+        Args:
+            bboxes: n x 4
+
+        Returns:
+            scaled_bboxes: n x 4
+        """
+        pass
+
+    @overload
+    def scale(
+        self: T,
+        ratio_wh: float,
+    ) -> T:
+        ...
+
+    @overload
+    def scale(
+        self: T,
+        ratio_wh: tuple[float, float],
+    ) -> T:
+        ...
+
+    def scale(self, ratio_wh):
+        if not isinstance(ratio_wh, tuple):
+            ratio_wh = (ratio_wh, ratio_wh)
+        return self._scale(self, ratio_wh)
 
 
 class BBoxesXY(BBoxes):
-    _BBoxType = NamedTuple(
-        '_BBoxType',
-        [('lt', torch.Tensor), ('rb', torch.Tensor)],
-    )
 
     @property
     def left(self) -> torch.Tensor:
@@ -287,34 +402,12 @@ class BBoxesXY(BBoxes):
     def lt(self) -> torch.Tensor:
         return self._bboxes[:, :2]
 
-    def _round_lt_rb(self) -> 'BBoxesXY._BBoxType':
-        lt = self.lt.floor()
-        rb = self.rb.ceil()
-        return self._BBoxType(lt, rb)
-
-    def _expand_lt_rb(
-        self,
-        ratio: float,
-        image_shape: Optional[Tuple[int, int]] = None,
-    ) -> 'BBoxesXY._BBoxType':
-        offsets = self.wh * (ratio - 1) / 2
-        lt = self.lt - offsets
-        rb = self.rb + offsets
-
-        lt.clamp_min_(0)
-        if image_shape is not None:
-            h, w = image_shape
-            rb[:, 0].clamp_max_(w)
-            rb[:, 1].clamp_max_(h)
-
-        return self._BBoxType(lt, rb)
-
 
 class BBoxesXYXY(BBoxesXY):
 
-    def __init__(self, *args, **kwargs) -> None:
-        super().__init__(*args, **kwargs)
-        assert self.wh.gt(0).all()
+    @staticmethod
+    def _convert(bboxes: BBoxes) -> torch.Tensor:
+        return torch.cat([bboxes.lt, bboxes.rb], dim=-1)
 
     @property
     def right(self) -> torch.Tensor:
@@ -353,25 +446,63 @@ class BBoxesXYXY(BBoxesXY):
         return (self.lt + self.rb) / 2
 
     @classmethod
-    def _round(cls: Type[T_XY], bboxes: T_XY) -> T_XY:
-        lt, rb = bboxes._round_lt_rb()
+    def _round(cls: type[T], bboxes: BBoxes) -> T:
+        lt = bboxes.lt.floor()
+        rb = bboxes.rb.ceil()
         rounded_bboxes = torch.cat([lt, rb], dim=-1)
         return cls(rounded_bboxes)
 
     @classmethod
     def _expand(
-        cls: Type[T_XY],
-        bboxes: T_XY,
-        ratio: float,
-        image_shape: Optional[Tuple[int, int]] = None,
-    ) -> T_XY:
-        lt, rb = bboxes._expand_lt_rb(ratio, image_shape)
-        expanded_bboxes = torch.cat([lt, rb], dim=-1)
+        cls: type[T],
+        bboxes: BBoxes,
+        ratio_wh: tuple[float, float],
+    ) -> T:
+        horizontal_offsets = bboxes.width * (ratio_wh[0] - 1) / 2
+        vertical_offsets = bboxes.height * (ratio_wh[1] - 1) / 2
+        left = bboxes.left - horizontal_offsets
+        top = bboxes.top - vertical_offsets
+        right = bboxes.right + horizontal_offsets
+        bottom = bboxes.bottom + vertical_offsets
+
+        expanded_bboxes = torch.stack([left, top, right, bottom], dim=-1)
         return cls(expanded_bboxes)
 
+    @classmethod
+    def _clamp(
+        cls: type[T],
+        bboxes: BBoxes,
+        image_wh: tuple[int, int],
+    ) -> T:
+        left = bboxes.left.clamp_min(0)
+        top = bboxes.top.clamp_min(0)
+        if image_wh is not None:
+            right = bboxes.right.clamp_max(image_wh[0])
+            bottom = bboxes.bottom.clamp_max(image_wh[1])
+        clamped_bboxes = torch.stack([left, top, right, bottom], dim=-1)
+        return cls(clamped_bboxes)
+
+    @classmethod
+    def _scale(
+        cls: type[T],
+        bboxes: BBoxes,
+        ratio_wh: tuple[float, float],
+    ) -> T:
+        left = bboxes.left * ratio_wh[0]
+        top = bboxes.top * ratio_wh[1]
+        right = bboxes.right * ratio_wh[0]
+        bottom = bboxes.bottom * ratio_wh[1]
+
+        scaled_bboxes = torch.stack([left, top, right, bottom], dim=-1)
+        return cls(scaled_bboxes)
+
 
 class BBoxesXYWH(BBoxesXY):
 
+    @staticmethod
+    def _convert(bboxes: BBoxes) -> torch.Tensor:
+        return torch.cat([bboxes.lt, bboxes.wh], dim=-1)
+
     @property
     def width(self) -> torch.Tensor:
         return self._bboxes[:, 2]
@@ -409,18 +540,31 @@ class BBoxesXYWH(BBoxesXY):
         return self.lt + self.wh / 2
 
     @classmethod
-    def _round(cls: Type[T_XY], bboxes: T_XY) -> T_XY:
-        lt, rb = bboxes._round_lt_rb()
-        rounded_bboxes = torch.cat([lt, rb - lt], dim=-1)
-        return cls(rounded_bboxes)
+    def _round(cls: type[T], bboxes: T) -> T:
+        return cls(BBoxesXYXY._round(bboxes))
 
     @classmethod
     def _expand(
-        cls: Type[T_XY],
-        bboxes: T_XY,
-        ratio: float,
-        image_shape: Optional[Tuple[int, int]] = None,
-    ) -> T_XY:
-        lt, rb = bboxes._expand_lt_rb(ratio, image_shape)
-        expanded_bboxes = torch.cat([lt, rb - lt], dim=-1)
-        return cls(expanded_bboxes)
+        cls: type[T],
+        bboxes: BBoxes,
+        ratio_wh: tuple[float, float],
+    ) -> T:
+        return cls(BBoxesXYXY._expand(bboxes, ratio_wh))
+
+    @classmethod
+    def _clamp(cls: type[T], bboxes: BBoxes, image_wh: tuple[int, int]) -> T:
+        return cls(BBoxesXYXY._clamp(bboxes, image_wh))
+
+    @classmethod
+    def _scale(
+        cls: type[T],
+        bboxes: BBoxes,
+        ratio_wh: tuple[float, float],
+    ) -> T:
+        left = bboxes.left * ratio_wh[0]
+        top = bboxes.top * ratio_wh[1]
+        width = bboxes.width * ratio_wh[0]
+        height = bboxes.height * ratio_wh[1]
+
+        scaled_bboxes = torch.stack([left, top, width, height], dim=-1)
+        return cls(scaled_bboxes)
