@@ -1,15 +1,18 @@
 __all__ = [
+    'HookRegistry',
     'BaseHook',
-    'HOOKS',
+    'HookStatus',
+    'hook',
 ]
 
+import contextlib
 from abc import abstractmethod
 from enum import IntEnum, auto
-from typing import TYPE_CHECKING, Protocol
+from typing import TYPE_CHECKING, Any, Generator, Protocol
 
 import torch.nn as nn
 
-from ..base import STEPS, Registry, StatusMixin, getattr_recur
+from ..base import Config, Registry, StatusMixin, get_
 
 if TYPE_CHECKING:
 
@@ -35,8 +38,11 @@ class _HookMixin(_HookProto):
         self.register_tensor(output)
 
     def bind(self, model: nn.Module) -> None:
-        module: nn.Module = getattr_recur(model, self._path)
-        module.register_forward_hook(self._forward_hook)
+        module: nn.Module = get_(model, self._path)
+        self._handle = module.register_forward_hook(self._forward_hook)
+
+    def unbind(self) -> None:
+        self._handle.remove()
 
 
 class _TrackingMixin(_HookProto):
@@ -54,10 +60,13 @@ class _TrackingMixin(_HookProto):
     def bind(self, model: nn.Module) -> None:
         self._model = model
 
+    def unbind(self) -> None:
+        delattr(self, '_model')
+
     def track_tensor(self) -> None:
         if not self._tracking_mode:
             raise AttributeError(f"Hook {self._path} does not support track.")
-        tensor = getattr_recur(self._model, self._path)
+        tensor = get_(self._model, self._path)
         self.register_tensor(tensor)
 
 
@@ -95,13 +104,6 @@ class BaseHook(StatusMixin[Status], _HookMixin, _TrackingMixin):
     def _tensor(self):
         pass
 
-    @StatusMixin.transit(
-        (Status.BINDED, Status.REGISTERED),
-        Status.BINDED,
-    )
-    def reset(self) -> None:
-        self._reset()
-
     @StatusMixin.transit(Status.INITIALIZED, Status.BINDED)
     def bind(self, model: nn.Module) -> None:
         if self._tracking_mode:
@@ -109,6 +111,13 @@ class BaseHook(StatusMixin[Status], _HookMixin, _TrackingMixin):
         else:
             _HookMixin.bind(self, model)
 
+    @StatusMixin.transit(Status.BINDED, Status.INITIALIZED)
+    def unbind(self) -> None:
+        if self._tracking_mode:
+            _TrackingMixin.unbind(self)
+        else:
+            _HookMixin.unbind(self)
+
     @StatusMixin.transit(
         (Status.BINDED, Status.REGISTERED),
         Status.REGISTERED,
@@ -116,9 +125,37 @@ class BaseHook(StatusMixin[Status], _HookMixin, _TrackingMixin):
     def register_tensor(self, tensor) -> None:
         self._register_tensor(tensor)
 
+    @StatusMixin.transit(
+        (Status.BINDED, Status.REGISTERED),
+        Status.BINDED,
+    )
+    def reset(self) -> None:
+        self._reset()
 
-HOOKS: Registry[BaseHook] = Registry(
-    'hooks',
-    parent=STEPS,
-    base=BaseHook,
-)
+
+class HookRegistry(Registry):
+    pass
+
+
+class HookStatus:
+    _value: Any
+
+    @property
+    def value(self):
+        return self._value
+
+
+@contextlib.contextmanager
+def hook(
+    config: Config,
+    model: nn.Module,
+) -> Generator[HookStatus, None, None]:
+    hook_ = HookRegistry.build(config)
+    hook_.bind(model)
+
+    status = HookStatus()
+    yield status
+    status._value = hook_()
+
+    hook_.reset()
+    hook_.unbind()
