@@ -1,17 +1,19 @@
-from typing import List
+__all__ = [
+    'MultiCallsHook',
+]
 
 import torch
 
-from .base import HOOKS, BaseHook
+from .base import BaseHook, HookRegistry
 
 
-@HOOKS.register_module()
+@HookRegistry.register()
 class MultiCallsHook(BaseHook):
 
     def _reset(self):
         self._tensors = []
 
-    def _tensor(self) -> List[torch.Tensor]:
+    def _tensor(self) -> list[torch.Tensor]:
         return self._tensors
 
     def _register_tensor(self, tensor: torch.Tensor) -> None:
