@@ -1,7 +1,11 @@
-from .base import HOOKS, BaseHook
+__all__ = [
+    'StandardHook',
+]
+
+from .base import BaseHook, HookRegistry
 
 
-@HOOKS.register_module()
+@HookRegistry.register()
 class StandardHook(BaseHook):
 
     def _reset(self):
