@@ -1,6 +1,11 @@
+__all__ = [
+    'FocalLoss',
+    'FocalWithLogitsLoss',
+]
+
 import torch
 
-from .base import LOSSES
+from .base import LossRegistry
 from .functional import BCELoss, BCEWithLogitsLoss, FunctionalLoss
 
 
@@ -35,11 +40,11 @@ class FocalMixin(FunctionalLoss):
         )
 
 
-@LOSSES.register_module()
+@LossRegistry.register()
 class FocalLoss(FocalMixin, BCELoss):
     pass
 
 
-@LOSSES.register_module()
+@LossRegistry.register()
 class FocalWithLogitsLoss(FocalMixin, BCEWithLogitsLoss):
     pass
