@@ -1,12 +1,47 @@
+__all__ = [
+    'L12DLoss',
+    'MSE2DLoss',
+    'FGDLoss',
+    'FGFILoss',
+]
+
 import einops
 import torch
 import torch.nn.functional as F
 
-from .base import LOSSES
-from .functional import MSE2DLoss
+from .base import LossRegistry
+from .functional import FunctionalLoss, L1Loss, MSELoss
 
 
-@LOSSES.register_module()
+class _2DMixin(FunctionalLoss):
+
+    def forward(
+        self,
+        pred: torch.Tensor,
+        target: torch.Tensor,
+        mask: torch.Tensor | None = None,
+        *args,
+        **kwargs,
+    ) -> torch.Tensor:
+        _, _, h, w = pred.shape
+        if pred.shape != target.shape:
+            target = F.adaptive_avg_pool2d(target, (h, w))
+        if mask is not None and pred.shape != mask.shape:
+            mask = F.adaptive_avg_pool2d(mask, (h, w))
+        return super().forward(pred, target, mask, *args, **kwargs)
+
+
+@LossRegistry.register()
+class L12DLoss(_2DMixin, L1Loss):
+    pass
+
+
+@LossRegistry.register()
+class MSE2DLoss(_2DMixin, MSELoss):
+    pass
+
+
+@LossRegistry.register()
 class FGFILoss(MSE2DLoss):
 
     def forward(  # type: ignore[override]
@@ -34,7 +69,7 @@ class FGFILoss(MSE2DLoss):
         )
 
 
-@LOSSES.register_module()
+@LossRegistry.register()
 class FGDLoss(MSE2DLoss):
 
     def forward(  # type: ignore[override]
@@ -60,7 +95,7 @@ class FGDLoss(MSE2DLoss):
         )
 
 
-# @LOSSES.register_module()
+# @LOSSES.register()
 # class LabelEncLoss(MSE2DLoss):
 
 #     def __init__(
@@ -99,11 +134,11 @@ class FGDLoss(MSE2DLoss):
 
 #     def forward(  # type: ignore[override]
 #         self,
-#         preds: List[torch.Tensor],
-#         targets: List[torch.Tensor],
+#         preds: list[torch.Tensor],
+#         targets: list[torch.Tensor],
 #         *args,
 #         **kwargs,
-#     ) -> List[torch.Tensor]:
+#     ) -> list[torch.Tensor]:
 #         losses = []
 #         for pred, target in zip(preds, targets):
 #             pred = self._adapt(pred)
@@ -112,7 +147,7 @@ class FGDLoss(MSE2DLoss):
 #             losses.append(loss)
 #         return losses
 
-# @LOSSES.register_module()
+# @LOSSES.register()
 # class DevLoss(MSE2DLoss):
 #     def __init__(self, pos_share: float = 1, *args, **kwargs):
 #         assert 0 <= pos_share <= 1
