@@ -1,16 +1,19 @@
-from typing import Callable, List
+__all__ = [
+    'SGFILoss',
+]
+
+from typing import Callable
 
 import einops
 import torch
 import torch.nn as nn
 import torch.nn.functional as F
-from mmcv.cnn import ConvModule
 
-from .base import LOSSES
+from .base import LossRegistry
 from .functional import MSELoss
 
 
-@LOSSES.register_module()
+@LossRegistry.register()
 class SGFILoss(MSELoss):
 
     def __init__(
@@ -21,6 +24,8 @@ class SGFILoss(MSELoss):
         out_channels: int = 64,
         **kwargs,
     ):
+        from mmcv.cnn import ConvModule
+
         super().__init__(*args, **kwargs)
         self._embed: Callable[..., torch.Tensor] = nn.Sequential(
             ConvModule(in_channels, hidden_channels, 3, stride=2),
@@ -30,7 +35,7 @@ class SGFILoss(MSELoss):
 
     def forward(  # type: ignore[override]
         self,
-        preds: List[torch.Tensor],
+        preds: list[torch.Tensor],
         targets: torch.Tensor,
         *args,
         **kwargs,
@@ -41,13 +46,13 @@ class SGFILoss(MSELoss):
 
         Args:
             pred: l x r x c x h x w
-                Each of the `l` levels generate `r` RoIs.
+                Each of the ``l`` levels generate ``r`` RoIs.
                 Typical shape is 4 x 1024 x 256 x 7 x 7.
 
             target: r x c x h x w
 
         Returns:
-            loss: 1
+            loss
         """
         fused_preds = torch.stack(preds)
         embed_pred = einops.rearrange(fused_preds, 'l r c h w -> (l r) c h w')
@@ -78,7 +83,7 @@ class SGFILoss(MSELoss):
         return super().forward(fused_pred, targets, *args, **kwargs)
 
 
-# @LOSSES.register_module()
+# @LOSSES.register()
 # class DevRCNNLoss(MSELoss):
 #     def __init__(
 #         self,
@@ -96,7 +101,7 @@ class SGFILoss(MSELoss):
 #         self._tau = nn.Parameter(torch.FloatTensor(data=[1]))
 
 #     def forward(
-#         self, preds: List[torch.Tensor], targets: torch.Tensor,
+#         self, preds: list[torch.Tensor], targets: torch.Tensor,
 #         poses: torch.Tensor,
 #         *args, **kwargs,
 #     ):
