@@ -1,23 +1,22 @@
+__all__ = [
+    'init_seed',
+    'set_seed_temp',
+]
+
 import hashlib
 import random
 from contextlib import contextmanager
-from typing import Generator, Optional, cast
+from typing import Generator, cast
 
 import numpy as np
 import torch
 import torch.backends.cudnn as cudnn
 import torch.distributed as dist
 
-from ..base import (
-    get_iter,
-    get_logger,
-    get_rank,
-    get_world_size,
-    iter_initialized,
-)
+from ..base import get_logger, get_rank, get_world_size
 
 
-def _randint(high: int = 2**30) -> int:
+def randint(high: int = 2**30) -> int:
     seed = np.random.randint(high)
     if get_world_size() <= 1:
         return seed
@@ -28,10 +27,10 @@ def _randint(high: int = 2**30) -> int:
 
 def init_seed(
     seed=None,
-    deterministic: Optional[bool] = None,
+    deterministic: bool | None = None,
 ) -> int:
     if seed is None:
-        seed = _randint()
+        seed = randint()
     elif isinstance(seed, int):
         pass
     else:
@@ -41,9 +40,6 @@ def init_seed(
         seed = int(seed, 16)
     seed %= 2**30
 
-    if iter_initialized():
-        seed += get_iter()
-
     random.seed(seed)
     np.random.seed(seed)
     torch.manual_seed(seed)
@@ -59,25 +55,31 @@ def init_seed(
 @contextmanager
 def set_seed_temp(
     seed=None,
-    deterministic: Optional[bool] = None,
+    deterministic: bool | None = None,
 ) -> Generator[None, None, None]:
+    cuda_is_available = torch.cuda.is_available()
     if torch.cuda.device_count() > 1:
         get_logger().warn(
             "Seeding is not recommended for multi-GPU training.",
         )
+
     random_state = random.getstate()
     np_state = np.random.get_state()
     torch_state = torch.get_rng_state()
-    cuda_state = torch.cuda.get_rng_state_all()
-    prev_detereministic = cudnn.deterministic
-    prev_benchmark = cudnn.benchmark
-    init_seed(seed, deterministic)
 
+    if cuda_is_available:
+        cuda_state = torch.cuda.get_rng_state()
+        prev_deterministic = cudnn.deterministic
+        prev_benchmark = cudnn.benchmark
+
+    init_seed(seed, deterministic)
     yield
 
     random.setstate(random_state)
     np.random.set_state(np_state)
     torch.set_rng_state(torch_state)
-    torch.cuda.set_rng_state_all(cuda_state)
-    cudnn.deterministic = prev_detereministic
-    cudnn.benchmark = prev_benchmark
+
+    if cuda_is_available:
+        torch.cuda.set_rng_state(cuda_state)
+        cudnn.deterministic = prev_deterministic
+        cudnn.benchmark = prev_benchmark
