@@ -1,5 +1,4 @@
 import argparse
-from typing import List
 
 import lmdb
 
@@ -22,21 +21,22 @@ def merge_txns(target_txn: lmdb.Transaction, source_txn: lmdb.Transaction):
 def merge_dbs(
     target_env: lmdb.Environment,
     source_env: lmdb.Environment,
-    dbs: List[str],
+    dbs: list[str],
 ):
     for db in dbs:
         target_db = target_env.open_db(db.encode())
         source_db = source_env.open_db(db.encode())
         with target_env.begin(
-            target_db, write=True,
+            target_db,
+            write=True,
         ) as target_txn, source_env.begin(source_db) as source_txn:
             merge_txns(target_txn, source_txn)
 
 
 def merge_envs(
     target_env: lmdb.Environment,
-    source_filepaths: List[str],
-    dbs: List[str],
+    source_filepaths: list[str],
+    dbs: list[str],
 ):
     for source_filepath in source_filepaths:
         with lmdb.open(
